==> odoo_19.0.20251016.zip: odoo-19.0.post20251016/odoo/addons/mail/static/src/discuss/core/web/messaging_menu_patch.js <==
import { DiscussSearch } from "@mail/core/public_web/discuss_search";
import { MessagingMenu } from "@mail/core/public_web/messaging_menu";
import { patch } from "@web/core/utils/patch";
import { useService } from "@web/core/utils/hooks";

Object.assign(MessagingMenu.components, { DiscussSearch });

patch(MessagingMenu.prototype, {
    setup() {
        super.setup();
        this.command = useService("command");
    },
    beforeOpen() {
        const res = super.beforeOpen(...arguments);
        this.store.channels.fetch();
        return res;
    },
    onClickNewMessage() {
        this.command.openMainPalette({ searchValue: "@" });
        if (!this.ui.isSmall && !this.env.inDiscussApp) {
            this.dropdown.close();
        }
    },
    get counter() {
        const count = super.counter;
        const channelsContribution =
            this.store.channels.status !== "fetched"
                ? this.store.initChannelsUnreadCounter
                : Object.values(this.store.Thread.records).filter(
                      (thread) =>
                          thread.displayToSelf &&
                          !thread.self_member_id?.mute_until_dt &&
                          (thread.self_member_id?.message_unread_counter ||
                              thread.message_needaction_counter)
                  ).length;
        // Needactions are already counted in the super call, but we want to discard them for channel so that there is only +1 per channel.
        const channelsNeedactionCounter = Object.values(this.store.Thread.records).reduce(
            (acc, thread) =>
                acc + (thread.model === "discuss.channel" ? thread.message_needaction_counter : 0),
            0
        );
        return count + channelsContribution - channelsNeedactionCounter;
    },
});

==> odoo_19.1a1.20251107.zip: odoo-19.1a1.post20251107/odoo/addons/mail/static/src/discuss/core/web/messaging_menu_patch.js <==
import { DiscussSearch } from "@mail/core/public_web/discuss_search";
import { MessagingMenu } from "@mail/core/public_web/messaging_menu";
import { patch } from "@web/core/utils/patch";
import { useService } from "@web/core/utils/hooks";

Object.assign(MessagingMenu.components, { DiscussSearch });

patch(MessagingMenu.prototype, {
    setup() {
        super.setup();
        this.command = useService("command");
    },
    beforeOpen() {
        const res = super.beforeOpen(...arguments);
        this.store.channels.fetch();
        return res;
    },
    onClickNewMessage() {
        this.command.openMainPalette({ searchValue: "@" });
        if (!this.ui.isSmall && !this.env.inDiscussApp) {
            this.dropdown.close();
        }
    },
    get counter() {
        const count = super.counter;
        const channelsContribution =
            this.store.channels.status !== "fetched"
                ? this.store.initChannelsUnreadCounter
                : Object.values(this.store["discuss.channel"].records).filter(
                      (channel) =>
                          channel.displayToSelf &&
                          !channel.self_member_id?.mute_until_dt &&
                          (channel.self_member_id?.message_unread_counter ||
                              channel.message_needaction_counter)
                  ).length;
        // Needactions are already counted in the super call, but we want to discard them for channel so that there is only +1 per channel.
        const channelsNeedactionCounter = Object.values(
            this.store["discuss.channel"].records
        ).reduce((acc, channel) => acc + channel.message_needaction_counter, 0);
        return count + channelsContribution - channelsNeedactionCounter;
    },
});
